## Usage

### Provide meaningful descriptions for SDC components

The assistant relies on component and slot descriptions to determine their suitability for a layout. Well-defined descriptions improve the accuracy of the generated structure.

### Update `settings.php`

This module leverages the AI Assistants and AI agents modules but requires some tweaks to the default prompts. Add the following lines to the `settings.php` to override the default prompts:

```php
$settings['ai_assistant_advanced_mode_enabled'] = TRUE;
$settings['ai_assistant_custom_prompts'] = TRUE;
```

### Enable installing test modules

Some modules from `experience_builder/tests/modules` must be enabled to use the extension feature. Add the following line to the `settings.php`:

```php
$settings['extension_discovery_scan_tests'] = TRUE;
```
```sh
dev drush en xb_dev_standard xb_dev_mode
```

### Setup any AI provider

(e.g., [AI Provider OpenAI](https://www.drupal.org/project/ai_provider_openai), [Gemini Provider](https://www.drupal.org/project/gemini_provider))

### Install the module

```sh
ddev drush en xb_ai_assistant -y
```

### Open the Experience Builder UI

Click on Extensions and select XB AI Assistant.

## Demo with Starshot Demo Design System (SDDS)

1. Install the Starshot Demo Design System theme with Experience Builder by following the official guide: [Starshot Demo Design System Development Guide](https://www.drupal.org/community-initiatives/starshot-demo-design-system/sdds-development-guide).

2. Apply the patch from `patches/sdds-sdc-info.patch`. This patch adds descriptions to the existing components:

  ```sh
  cd starshot
  patch -d web/themes/contrib/demo_design_system/ -p1 < web/modules/contrib/xb_ai_assistant/patches/sdds-sdc-info.patch
  ```

3. Add the following line to the `settings.php` to use only the SDDS components:

  ```php
  $settings['xb_ai_assistant_ignore_xb_sdc'] = TRUE;
  ```

4. Setup any AI provider (e.g., [AI Provider OpenAI](https://www.drupal.org/project/ai_provider_openai), [Gemini Provider](https://www.drupal.org/project/gemini_provider)).

5. Install the module.

6. Open the Experience Builder UI.

7. Click on Extensions and select XB AI Assistant.
