<?php

declare(strict_types=1);

namespace Drupal\xb_ai_assistant\Controller;

use Drupal\ai\OperationType\Chat\ChatOutput;
use Drupal\ai_assistant_api\AiAssistantApiRunner;
use Drupal\ai_assistant_api\Data\UserMessage;
use Drupal\Component\Serialization\Json;
use Drupal\Core\Controller\ControllerBase;
use Symfony\Component\DependencyInjection\ContainerInterface;
use Symfony\Component\HttpFoundation\JsonResponse;
use Symfony\Component\HttpFoundation\Request;

/**
 * Returns responses for xb ai assitant routes.
 */
final class XbAssistantController extends ControllerBase {

  /**
   * The controller constructor.
   */
  public function __construct(
    protected AiAssistantApiRunner $aiAssistantClient,
  ) {}

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container): self {
    return new static(
      $container->get('ai_assistant_api.runner'),
    );
  }

  /**
   * Builds the response.
   */
  public function __invoke(Request $request): JsonResponse {
    $request_content = Json::decode($request->getContent(), TRUE);
    $assistant = $this->entityTypeManager()->getStorage('ai_assistant')->load('xb_ai_assistant');
    $this->aiAssistantClient->setAssistant($assistant);
    $user_input = $request_content['prompt'] ?? '';
    $entity_type = $request_content['entityType'] ?? '';
    $entity_id = $request_content['entityId'] ?? '';
    $selected_component = $request_content['selectedComponent'] ?? 'None';
    $user_input = sprintf("%s\nPage details: entity_type: %s, entity_id: %s, selected_component: %s", $user_input, $entity_type, $entity_id, $selected_component);
    $user_input = new UserMessage($user_input);
    $this->aiAssistantClient->setUserMessage($user_input);
    $this->aiAssistantClient->setThrowException(TRUE);

    try {
      $response = $this->aiAssistantClient->process();
      assert($response instanceof ChatOutput);

      // Handle the response.
      $normalizedResponse = $response->getNormalized()->getText();
      return new JsonResponse(['message' => $normalizedResponse]);
    }
    catch (\Exception $e) {
      $error_message = $assistant->get('error_message');

      // Otherwise use the default error message.
      return new JsonResponse([
        'message' => $error_message,
      ]);
    }
  }

}
